@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Wavefront Python SDK.
 
 This library provides support for sending metrics, histograms and opentracing
@@ -9,11 +8,14 @@ spans to Wavefront via proxy or direct ingestion.
 
 import pkg_resources
 
+from .client_factory import WavefrontClientFactory
 from .direct import WavefrontDirectClient
 from .proxy import WavefrontProxyClient
 
 
-__all__ = ['WavefrontDirectClient', 'WavefrontProxyClient']
+__all__ = ['WavefrontDirectClient',
+           'WavefrontProxyClient',
+           'WavefrontClientFactory']
 
 __version__ = None
 
