@@ -12,7 +12,7 @@ class WavefrontSdkCounter(metrics.WavefrontSdkMetric):
 
     def __init__(self):
         """Construct Wavefront SDK Counter."""
-        self._lock = threading.Lock()
+        self._lock = threading.RLock()
         self._count = 0
 
     def inc(self, val=1):
